@@ -44,7 +44,15 @@ from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 class CloudComposerHook(GoogleBaseHook):
     """Hook for Google Cloud Composer APIs."""
 
-    client_options = ClientOptions(api_endpoint='composer.googleapis.com:443')
+    client_options = ClientOptions(api_endpoint="composer.googleapis.com:443")
+
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
 
     def get_environment_client(self) -> EnvironmentsClient:
         """Retrieves client library object that allow access Environments service."""
@@ -54,9 +62,7 @@ class CloudComposerHook(GoogleBaseHook):
             client_options=self.client_options,
         )
 
-    def get_image_versions_client(
-        self,
-    ) -> ImageVersionsClient:
+    def get_image_versions_client(self) -> ImageVersionsClient:
         """Retrieves client library object that allow access Image Versions service."""
         return ImageVersionsClient(
             credentials=self.get_credentials(),
@@ -76,10 +82,10 @@ class CloudComposerHook(GoogleBaseHook):
         return self.get_environment_client().transport.operations_client.get_operation(name=operation_name)
 
     def get_environment_name(self, project_id, region, environment_id):
-        return f'projects/{project_id}/locations/{region}/environments/{environment_id}'
+        return f"projects/{project_id}/locations/{region}/environments/{environment_id}"
 
     def get_parent(self, project_id, region):
-        return f'projects/{project_id}/locations/{region}'
+        return f"projects/{project_id}/locations/{region}"
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_environment(
@@ -104,7 +110,7 @@ class CloudComposerHook(GoogleBaseHook):
         """
         client = self.get_environment_client()
         result = client.create_environment(
-            request={'parent': self.get_parent(project_id, region), 'environment': environment},
+            request={"parent": self.get_parent(project_id, region), "environment": environment},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -159,7 +165,7 @@ class CloudComposerHook(GoogleBaseHook):
         """
         client = self.get_environment_client()
         result = client.get_environment(
-            request={'name': self.get_environment_name(project_id, region, environment_id)},
+            request={"name": self.get_environment_name(project_id, region, environment_id)},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
@@ -271,7 +277,7 @@ class CloudComposerHook(GoogleBaseHook):
         client = self.get_image_versions_client()
         result = client.list_image_versions(
             request={
-                'parent': self.get_parent(project_id, region),
+                "parent": self.get_parent(project_id, region),
                 "page_size": page_size,
                 "page_token": page_token,
                 "include_past_releases": include_past_releases,
@@ -286,7 +292,15 @@ class CloudComposerHook(GoogleBaseHook):
 class CloudComposerAsyncHook(GoogleBaseHook):
     """Hook for Google Cloud Composer async APIs."""
 
-    client_options = ClientOptions(api_endpoint='composer.googleapis.com:443')
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
+    client_options = ClientOptions(api_endpoint="composer.googleapis.com:443")
 
     def get_environment_client(self) -> EnvironmentsAsyncClient:
         """Retrieves client library object that allow access Environments service."""
@@ -297,10 +311,10 @@ class CloudComposerAsyncHook(GoogleBaseHook):
         )
 
     def get_environment_name(self, project_id, region, environment_id):
-        return f'projects/{project_id}/locations/{region}/environments/{environment_id}'
+        return f"projects/{project_id}/locations/{region}/environments/{environment_id}"
 
     def get_parent(self, project_id, region):
-        return f'projects/{project_id}/locations/{region}'
+        return f"projects/{project_id}/locations/{region}"
 
     async def get_operation(self, operation_name):
         return await self.get_environment_client().transport.operations_client.get_operation(
@@ -330,7 +344,7 @@ class CloudComposerAsyncHook(GoogleBaseHook):
         """
         client = self.get_environment_client()
         return await client.create_environment(
-            request={'parent': self.get_parent(project_id, region), 'environment': environment},
+            request={"parent": self.get_parent(project_id, region), "environment": environment},
             retry=retry,
             timeout=timeout,
             metadata=metadata,
