@@ -20,7 +20,6 @@ from __future__ import annotations
 
 import time
 import uuid
-import warnings
 from typing import Any, Sequence
 
 from google.api_core.client_options import ClientOptions
@@ -28,6 +27,7 @@ from google.api_core.exceptions import ServerError
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.operation import Operation
 from google.api_core.operation_async import AsyncOperation
+from google.api_core.operations_v1.operations_client import OperationsClient
 from google.api_core.retry import Retry
 from google.cloud.dataproc_v1 import (
     Batch,
@@ -208,14 +208,15 @@ class DataprocHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
-        super().__init__(gcp_conn_id, delegate_to, impersonation_chain)
+        super().__init__(gcp_conn_id=gcp_conn_id, impersonation_chain=impersonation_chain)
 
     def get_cluster_client(self, region: str | None = None) -> ClusterControllerClient:
         """Returns ClusterControllerClient."""
@@ -985,6 +986,68 @@ class DataprocHook(GoogleBaseHook):
         )
         return result
 
+    @GoogleBaseHook.fallback_to_default_project_id
+    def wait_for_batch(
+        self,
+        batch_id: str,
+        region: str,
+        project_id: str,
+        wait_check_interval: int = 10,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ) -> Batch:
+        """
+        Wait for a Batch job to complete.
+
+        After Batch job submission, the operator will wait for the job to complete, however, this is useful
+        in the case where Airflow is restarted or the task pid is killed for any reason. In this case, the
+        Batch create will happen again, AlreadyExists will be raised and caught, then should fall to this
+        function for waiting on completion.
+
+        :param batch_id: Required. The ID to use for the batch, which will become the final component
+            of the batch's resource name.
+            This value must be 4-63 characters. Valid characters are /[a-z][0-9]-/.
+        :param region: Required. The Cloud Dataproc region in which to handle the request.
+        :param project_id: Required. The ID of the Google Cloud project that the cluster belongs to.
+        :param wait_check_interval: The amount of time to pause between checks for job completion
+        :param retry: A retry object used to retry requests to get_batch.
+            If ``None`` is specified, requests will not be retried.
+        :param timeout: The amount of time, in seconds, to wait for the create_batch request to complete.
+            Note that if ``retry`` is specified, the timeout applies to each individual attempt.
+        :param metadata: Additional metadata that is provided to the method.
+        """
+        state = None
+        first_loop: bool = True
+        while state not in [
+            Batch.State.CANCELLED,
+            Batch.State.FAILED,
+            Batch.State.SUCCEEDED,
+            Batch.State.STATE_UNSPECIFIED,
+        ]:
+            try:
+                if not first_loop:
+                    time.sleep(wait_check_interval)
+                first_loop = False
+                self.log.debug("Waiting for batch %s", batch_id)
+                result = self.get_batch(
+                    batch_id=batch_id,
+                    region=region,
+                    project_id=project_id,
+                    retry=retry,
+                    timeout=timeout,
+                    metadata=metadata,
+                )
+                state = result.state
+            except ServerError as err:
+                self.log.info(
+                    "Retrying. Dataproc API returned server error when waiting for batch id %s: %s",
+                    batch_id,
+                    err,
+                )
+
+        return result
+
 
 class DataprocAsyncHook(GoogleBaseHook):
     """
@@ -997,10 +1060,15 @@ class DataprocAsyncHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        super().__init__(gcp_conn_id, delegate_to, impersonation_chain)
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(gcp_conn_id=gcp_conn_id, impersonation_chain=impersonation_chain)
         self._cached_client: JobControllerAsyncClient | None = None
 
     def get_cluster_client(self, region: str | None = None) -> ClusterControllerAsyncClient:
@@ -1047,6 +1115,10 @@ class DataprocAsyncHook(GoogleBaseHook):
             credentials=self.get_credentials(), client_info=CLIENT_INFO, client_options=client_options
         )
 
+    def get_operations_client(self, region: str) -> OperationsClient:
+        """Returns OperationsClient"""
+        return self.get_template_client(region=region).transport.operations_client
+
     @GoogleBaseHook.fallback_to_default_project_id
     async def create_cluster(
         self,
@@ -1459,6 +1531,9 @@ class DataprocAsyncHook(GoogleBaseHook):
         )
         return operation
 
+    async def get_operation(self, region, operation_name):
+        return await self.get_operations_client(region).get_operation(name=operation_name)
+
     @GoogleBaseHook.fallback_to_default_project_id
     async def get_job(
         self,
