@@ -59,7 +59,7 @@ class CloudSpeechToTextHook(GoogleBaseHook):
             gcp_conn_id=gcp_conn_id,
             impersonation_chain=impersonation_chain,
         )
-        self._client = None
+        self._client: SpeechClient | None = None
 
     def get_conn(self) -> SpeechClient:
         """
@@ -92,6 +92,11 @@ class CloudSpeechToTextHook(GoogleBaseHook):
             Note that if retry is specified, the timeout applies to each individual attempt.
         """
         client = self.get_conn()
+        if isinstance(config, dict):
+            config = RecognitionConfig(config)
+        if isinstance(audio, dict):
+            audio = RecognitionAudio(audio)
+
         response = client.recognize(config=config, audio=audio, retry=retry, timeout=timeout)
         self.log.info("Recognised speech: %s", response)
         return response
