@@ -39,12 +39,16 @@ class StackdriverHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._policy_client = None
@@ -105,10 +109,10 @@ class StackdriverHook(GoogleBaseHook):
         client = self._get_policy_client()
         policies_ = client.list_alert_policies(
             request={
-                'name': f'projects/{project_id}',
-                'filter': filter_,
-                'order_by': order_by,
-                'page_size': page_size,
+                "name": f"projects/{project_id}",
+                "filter": filter_,
+                "order_by": order_by,
+                "page_size": page_size,
             },
             retry=retry,
             timeout=timeout,
@@ -136,9 +140,9 @@ class StackdriverHook(GoogleBaseHook):
         for policy in policies_:
             if policy.enabled != bool(new_state):
                 policy.enabled = bool(new_state)
-                mask = FieldMask(paths=['enabled'])
+                mask = FieldMask(paths=["enabled"])
                 client.update_alert_policy(
-                    request={'alert_policy': policy, 'update_mask': mask},
+                    request={"alert_policy": policy, "update_mask": mask},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -240,11 +244,11 @@ class StackdriverHook(GoogleBaseHook):
 
         record = json.loads(alerts)
         existing_policies = [
-            policy['name'] for policy in self.list_alert_policies(project_id=project_id, format_='dict')
+            policy["name"] for policy in self.list_alert_policies(project_id=project_id, format_="dict")
         ]
         existing_channels = [
-            channel['name']
-            for channel in self.list_notification_channels(project_id=project_id, format_='dict')
+            channel["name"]
+            for channel in self.list_notification_channels(project_id=project_id, format_="dict")
         ]
         policies_ = []
         channels = []
@@ -262,7 +266,7 @@ class StackdriverHook(GoogleBaseHook):
 
             if channel.name in existing_channels:
                 channel_client.update_notification_channel(
-                    request={'notification_channel': channel},
+                    request={"notification_channel": channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -271,7 +275,7 @@ class StackdriverHook(GoogleBaseHook):
                 old_name = channel.name
                 channel.name = None
                 new_channel = channel_client.create_notification_channel(
-                    request={'name': f'projects/{project_id}', 'notification_channel': channel},
+                    request={"name": f"projects/{project_id}", "notification_channel": channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -290,7 +294,7 @@ class StackdriverHook(GoogleBaseHook):
             if policy.name in existing_policies:
                 try:
                     policy_client.update_alert_policy(
-                        request={'alert_policy': policy},
+                        request={"alert_policy": policy},
                         retry=retry,
                         timeout=timeout,
                         metadata=metadata,
@@ -302,7 +306,7 @@ class StackdriverHook(GoogleBaseHook):
                 for condition in policy.conditions:
                     condition.name = None
                 policy_client.create_alert_policy(
-                    request={'name': f'projects/{project_id}', 'alert_policy': policy},
+                    request={"name": f"projects/{project_id}", "alert_policy": policy},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -330,10 +334,10 @@ class StackdriverHook(GoogleBaseHook):
         policy_client = self._get_policy_client()
         try:
             policy_client.delete_alert_policy(
-                request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+                request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ()
             )
         except HttpError as err:
-            raise AirflowException(f'Delete alerting policy failed. Error was {err.content}')
+            raise AirflowException(f"Delete alerting policy failed. Error was {err.content}")
 
     @GoogleBaseHook.fallback_to_default_project_id
     def list_notification_channels(
@@ -380,10 +384,10 @@ class StackdriverHook(GoogleBaseHook):
         client = self._get_channel_client()
         channels = client.list_notification_channels(
             request={
-                'name': f'projects/{project_id}',
-                'filter': filter_,
-                'order_by': order_by,
-                'page_size': page_size,
+                "name": f"projects/{project_id}",
+                "filter": filter_,
+                "order_by": order_by,
+                "page_size": page_size,
             },
             retry=retry,
             timeout=timeout,
@@ -408,14 +412,14 @@ class StackdriverHook(GoogleBaseHook):
     ) -> None:
         client = self._get_channel_client()
         channels = client.list_notification_channels(
-            request={'name': f'projects/{project_id}', 'filter': filter_}
+            request={"name": f"projects/{project_id}", "filter": filter_}
         )
         for channel in channels:
             if channel.enabled != bool(new_state):
                 channel.enabled = bool(new_state)
-                mask = FieldMask(paths=['enabled'])
+                mask = FieldMask(paths=["enabled"])
                 client.update_notification_channel(
-                    request={'notification_channel': channel, 'update_mask': mask},
+                    request={"notification_channel": channel, "update_mask": mask},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -532,7 +536,7 @@ class StackdriverHook(GoogleBaseHook):
 
             if channel.name in existing_channels:
                 channel_client.update_notification_channel(
-                    request={'notification_channel': channel},
+                    request={"notification_channel": channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -541,7 +545,7 @@ class StackdriverHook(GoogleBaseHook):
                 old_name = channel.name
                 channel.name = None
                 new_channel = channel_client.create_notification_channel(
-                    request={'name': f'projects/{project_id}', 'notification_channel': channel},
+                    request={"name": f"projects/{project_id}", "notification_channel": channel},
                     retry=retry,
                     timeout=timeout,
                     metadata=metadata,
@@ -572,7 +576,7 @@ class StackdriverHook(GoogleBaseHook):
         channel_client = self._get_channel_client()
         try:
             channel_client.delete_notification_channel(
-                request={'name': name}, retry=retry, timeout=timeout, metadata=metadata or ()
+                request={"name": name}, retry=retry, timeout=timeout, metadata=metadata or ()
             )
         except HttpError as err:
-            raise AirflowException(f'Delete notification channel failed. Error was {err.content}')
+            raise AirflowException(f"Delete notification channel failed. Error was {err.content}")
