@@ -39,6 +39,14 @@ class WorkflowsHook(GoogleBaseHook):
     keyword arguments rather than positional.
     """
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     def get_workflows_client(self) -> WorkflowsClient:
         """Returns WorkflowsClient."""
         return WorkflowsClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
