@@ -15,7 +15,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a link for GCS Storage assets."""
-from typing import TYPE_CHECKING, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.links.base import BaseGoogleLink
@@ -36,11 +38,11 @@ class StorageLink(BaseGoogleLink):
     format_str = GCS_STORAGE_LINK
 
     @staticmethod
-    def persist(context: "Context", task_instance, uri: str):
+    def persist(context: Context, task_instance, uri: str, project_id: str | None):
         task_instance.xcom_push(
             context=context,
             key=StorageLink.key,
-            value={"uri": uri, "project_id": task_instance.project_id},
+            value={"uri": uri, "project_id": project_id},
         )
 
 
@@ -52,7 +54,7 @@ class FileDetailsLink(BaseGoogleLink):
     format_str = GCS_FILE_DETAILS_LINK
 
     @staticmethod
-    def persist(context: "Context", task_instance: BaseOperator, uri: str, project_id: Optional[str]):
+    def persist(context: Context, task_instance: BaseOperator, uri: str, project_id: str | None):
         task_instance.xcom_push(
             context=context,
             key=FileDetailsLink.key,
